#ifdef __cplusplus
extern "C" {
#endif

#include "uulib/copy.h"

#ifdef __cplusplus
}
#endif

void uu_copy_binary(pUCXT, const uu_t in, uu_t out) {
  U8  *cp1 = (U8*)&in;
  U8  *cp2 = out;
  UV  i;

  for (i=0; i < 16; i++)
    *cp1++ = *cp2++;
}

void uu_copy_struct(pUCXT, const struct uu *in, struct uu *out) {
  out->time_low = in->time_low;
  out->time_mid = in->time_mid;
  out->time_high_and_version = in->time_high_and_version;
  out->clock_seq_and_variant = in->clock_seq_and_variant;
  out->node[0] = in->node[0];
  out->node[1] = in->node[1];
  out->node[2] = in->node[2];
  out->node[3] = in->node[3];
  out->node[4] = in->node[4];
  out->node[5] = in->node[5];
}

/* ex:set ts=2 sw=2 itab=spaces: */
